==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/S3d52b4397df4d4d0e426da5d85159dbf.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"

#include "S3d52b4397df4d4d0e426da5d85159dbf.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S37db707ef4875cd03a3e81050c508792.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#if HAVE_SYS_STAT_H
 
#include <sys/stat.h>

#endif
 
#if HAVE_UNISTD_H
 
#include <unistd.h>

#endif
 
#if HAVE_FCNTL_H
 
#include <fcntl.h>

#endif
 
#ifdef macintosh
 
#include <Files.h>

#endif
  S478df734a41b1d39ac090c596aa03a33::S478df734a41b1d39ac090c596aa03a33(const S749d2b576e15d77f0d14f186077e9ace 
&Sbb07b3c5b00dfd87361ec6708940420f) { Sbe05d559ccc3262d3e7d034ed3c56980 = Sbb07b3c5b00dfd87361ec6708940420f; 

#ifdef WIN32
 S93abd35af93cd4151ac748cdf3684a67 = NULL; 
#else
 
#ifdef macintosh
 S8b94d212e321a4832223afb4d8f144b2 = 0; 
#else
 S522acd1179ffb040a67d6cd2eae0bfed = -1; 
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = false; }   S478df734a41b1d39ac090c596aa03a33::~S478df734a41b1d39ac090c596aa03a33(void) 
{ 
#ifdef WIN32
 if (S93abd35af93cd4151ac748cdf3684a67) S87128efd365556f262f38b77b5299d52(S93abd35af93cd4151ac748cdf3684a67); 

#endif
 }   void S478df734a41b1d39ac090c596aa03a33::S5d7e68057b21f3ecee10cd5a1c1b9be2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179) {   
#ifdef BEOS
 return; 
#endif
 
#ifdef WIN32
  if (S93abd35af93cd4151ac748cdf3684a67 == NULL) { S93abd35af93cd4151ac748cdf3684a67 = Sf83dd7896428e470a486020feb820863(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), 
Sa716da310c9144cc48bd35abeaa6046c, S86f27b9e7b73afc707983aa380facd4c | Sf5abdedce59acf95a3b2d026113c87f4, 
NULL, S05f81d2836a37915d9d58fc44dbb4d73, S8eb60a48219e0a7a97f659a17c91f6dd, NULL); if (S93abd35af93cd4151ac748cdf3684a67 
== NULL) Sdc89a30d4c97fd8b60329797e2883ba8("Can't access lock file " << Sbe05d559ccc3262d3e7d034ed3c56980); 
}  
#if 0
  S9cfe110ae43252e200f2d562efc30ce4 Sf19155784c00c0c252a8b4dba353c5b8; Sf19155784c00c0c252a8b4dba353c5b8.Sf4cf1d86b530dbebd06cee08975e92df 
= NULL; Sf19155784c00c0c252a8b4dba353c5b8.Sdfd0a82c4bf37b1e90b690a22a20692e = 0; Sf19155784c00c0c252a8b4dba353c5b8.S945b48d96fc68bd3d808df6c6185e5b4 
= 0; Sa97b2c144243b2b9d2c593ec268b62f5 Sd102f4518237f1d5d18e6b8fb7febe08 = S3d06676fb9dae6b98c16004369633cd3( 
S06bb0c9eea34e27a7d0e1ca3958523ec,  Sae847b1574bf8ea5b86e162845f53a4e,  0,  1,  0,  &Sf19155784c00c0c252a8b4dba353c5b8 
 ); 
#endif
 Sa97b2c144243b2b9d2c593ec268b62f5 Sd102f4518237f1d5d18e6b8fb7febe08; do{ Sd102f4518237f1d5d18e6b8fb7febe08 
= Sa79d67fb02596fa7127128c3973ec66b(S93abd35af93cd4151ac748cdf3684a67, 0, 0, 1, 0); } while (Sd102f4518237f1d5d18e6b8fb7febe08 
== 0); 
#else
 
#ifdef macintosh
   Sa0ba729837649699e981a4a2ead7ae63 Sb979c2934ac0b4ba3f08dabfdd1b2299; S810b47b3098d1c2af29fe6d2e073c11e 
Sffb3bd546dd1ce6c27d1ac9c2ec68ad8; S63b3a7932b8b150c7ddbaf732378b4b6(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), 
Sffb3bd546dd1ce6c27d1ac9c2ec68ad8); S528ca7ae10b9304dce67f7af7d73ca9f S56bd7107802ebe56c6918992f0608ec6 
= S94ad216f2d84942a661fb50cff62db12(0, 0, Sffb3bd546dd1ce6c27d1ac9c2ec68ad8, &Sb979c2934ac0b4ba3f08dabfdd1b2299); 
if (S56bd7107802ebe56c6918992f0608ec6 == S15cd745376460ee263646e4767748a83) { S56bd7107802ebe56c6918992f0608ec6 
= Sce7362cdbc237321a33646654654792e(&Sb979c2934ac0b4ba3f08dabfdd1b2299, 'S@wM', 'lock', S3ba5a6dd400eb5f7c49b56ddd13ddc22); 
if (S56bd7107802ebe56c6918992f0608ec6) { Sdc89a30d4c97fd8b60329797e2883ba8("Can't create lock file " 
<< Sbe05d559ccc3262d3e7d034ed3c56980); } }  do { S56bd7107802ebe56c6918992f0608ec6 = S1ea2e7b1ab595dd458729009b7e43039(&Sb979c2934ac0b4ba3f08dabfdd1b2299, 
S66dff7d037506ab17e996664a5c4eaca, &S8b94d212e321a4832223afb4d8f144b2); Sbda1f40e5c4ff203630569b4b9af3bf3; 
} while (S56bd7107802ebe56c6918992f0608ec6 == Sb36e48bcd9421fee71b8e586f8b88bb7); 
#else
  if (S522acd1179ffb040a67d6cd2eae0bfed == -1) {   Sf7ffeb350c9235cbf230290106a2d733(S4d682ec4eed27c53849758bc13b6e179, 
0777);  S522acd1179ffb040a67d6cd2eae0bfed = open(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), O_RDWR | 
O_CREAT, 0777); if (S522acd1179ffb040a67d6cd2eae0bfed == -1) 
#ifndef MINGW
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't open lock file " << Sbe05d559ccc3262d3e7d034ed3c56980 << " (" 
<< strerror(errno) << ")");
#else
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't open lock file " << Sbe05d559ccc3262d3e7d034ed3c56980);
#endif
  }  struct flock Sbc7b36fe4d2924e49800d9b3dc4a325c; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_type = F_WRLCK; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_whence = SEEK_SET; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_start = 0; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_len = 0; int Scb5e100e5a9a3e7f6d1fd97512215282 = fcntl(S522acd1179ffb040a67d6cd2eae0bfed, 
F_SETLKW, &Sbc7b36fe4d2924e49800d9b3dc4a325c); if (Scb5e100e5a9a3e7f6d1fd97512215282 == -1) Sdc89a30d4c97fd8b60329797e2883ba8("Can't lock database file: " 
<< strerror(errno));  
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = true; }   void S478df734a41b1d39ac090c596aa03a33::S0f42007614120ad55ee822b263a2982b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179) {   
#ifdef BEOS
 return; 
#endif
 
#ifdef WIN32
 Sa97b2c144243b2b9d2c593ec268b62f5 Sb37404a6d1ace1967f608146811fd739 = Se9fe22126bcdd89c9b1fe87ac3658672(S93abd35af93cd4151ac748cdf3684a67, 
0, 0, 1, 0); if (Sb37404a6d1ace1967f608146811fd739 == 0) 
#ifdef MINGW
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file"); 
#else
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file: " << strerror(errno)); 
#endif
 
#else
 
#ifdef macintosh
  S8744d5cbc40c3f66630f767f7b55d734(S8b94d212e321a4832223afb4d8f144b2); 
#else
  struct flock Sbc7b36fe4d2924e49800d9b3dc4a325c; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_type = F_UNLCK; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_whence = SEEK_SET; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_start = 0; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_len = 0; int Scb5e100e5a9a3e7f6d1fd97512215282 = fcntl(S522acd1179ffb040a67d6cd2eae0bfed, 
F_SETLKW, &Sbc7b36fe4d2924e49800d9b3dc4a325c); if (Scb5e100e5a9a3e7f6d1fd97512215282 == -1) Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file: " 
<< strerror(errno)); 
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = false; }

==> sawmill6.5b3_crypt_src.tar.gz: sawmill-6.5b3/S3d52b4397df4d4d0e426da5d85159dbf.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "sconfig.h"

#include "S3d52b4397df4d4d0e426da5d85159dbf.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S3fe890ac3c9cdf3a851cca932627ecf4.h"

#include "S37db707ef4875cd03a3e81050c508792.h"

#include "S033c90fd2ff4888be82b5e1092fc89eb.h"
 
#if HAVE_SYS_TYPES_H
 
#include <sys/types.h>

#endif
 
#if HAVE_SYS_STAT_H
 
#include <sys/stat.h>

#endif
 
#if HAVE_UNISTD_H
 
#include <unistd.h>

#endif
 
#if HAVE_FCNTL_H
 
#include <fcntl.h>

#endif
 
#ifdef macintosh
 
#include <Files.h>

#endif
  S478df734a41b1d39ac090c596aa03a33::S478df734a41b1d39ac090c596aa03a33(const S749d2b576e15d77f0d14f186077e9ace 
&Sbb07b3c5b00dfd87361ec6708940420f) { Sbe05d559ccc3262d3e7d034ed3c56980 = Sbb07b3c5b00dfd87361ec6708940420f; 

#ifdef WIN32
 S93abd35af93cd4151ac748cdf3684a67 = NULL; 
#else
 
#ifdef macintosh
 S8b94d212e321a4832223afb4d8f144b2 = 0; 
#else
 S522acd1179ffb040a67d6cd2eae0bfed = -1; 
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = false; }   S478df734a41b1d39ac090c596aa03a33::~S478df734a41b1d39ac090c596aa03a33(void) 
{ 
#ifdef WIN32
 if (S93abd35af93cd4151ac748cdf3684a67) S87128efd365556f262f38b77b5299d52(S93abd35af93cd4151ac748cdf3684a67); 

#endif
 }   void S478df734a41b1d39ac090c596aa03a33::S5d7e68057b21f3ecee10cd5a1c1b9be2(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179) {  if (!S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.S6ababfc7c45c15a7da3db360b25546cb) 
return;   
#ifdef BEOS
 return; 
#endif
 
#ifdef WIN32
  if (S93abd35af93cd4151ac748cdf3684a67 == NULL) { S93abd35af93cd4151ac748cdf3684a67 = Sf83dd7896428e470a486020feb820863(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), 
Sa716da310c9144cc48bd35abeaa6046c, S86f27b9e7b73afc707983aa380facd4c | Sf5abdedce59acf95a3b2d026113c87f4, 
NULL, S05f81d2836a37915d9d58fc44dbb4d73, S8eb60a48219e0a7a97f659a17c91f6dd, NULL); if (S93abd35af93cd4151ac748cdf3684a67 
== NULL) Sdc89a30d4c97fd8b60329797e2883ba8("Can't access lock file " << Sbe05d559ccc3262d3e7d034ed3c56980); 
}  
#if 0
  S9cfe110ae43252e200f2d562efc30ce4 Sf19155784c00c0c252a8b4dba353c5b8; Sf19155784c00c0c252a8b4dba353c5b8.Sf4cf1d86b530dbebd06cee08975e92df 
= NULL; Sf19155784c00c0c252a8b4dba353c5b8.Sdfd0a82c4bf37b1e90b690a22a20692e = 0; Sf19155784c00c0c252a8b4dba353c5b8.S945b48d96fc68bd3d808df6c6185e5b4 
= 0; Sa97b2c144243b2b9d2c593ec268b62f5 Sd102f4518237f1d5d18e6b8fb7febe08 = S3d06676fb9dae6b98c16004369633cd3( 
S06bb0c9eea34e27a7d0e1ca3958523ec,  Sae847b1574bf8ea5b86e162845f53a4e,  0,  1,  0,  &Sf19155784c00c0c252a8b4dba353c5b8 
 ); 
#endif
 Sa97b2c144243b2b9d2c593ec268b62f5 Sd102f4518237f1d5d18e6b8fb7febe08; do{ Sd102f4518237f1d5d18e6b8fb7febe08 
= Sa79d67fb02596fa7127128c3973ec66b(S93abd35af93cd4151ac748cdf3684a67, 0, 0, 1, 0); } while (Sd102f4518237f1d5d18e6b8fb7febe08 
== 0); 
#else
 
#ifdef macintosh
   Sa0ba729837649699e981a4a2ead7ae63 Sb979c2934ac0b4ba3f08dabfdd1b2299; S810b47b3098d1c2af29fe6d2e073c11e 
Sffb3bd546dd1ce6c27d1ac9c2ec68ad8; S63b3a7932b8b150c7ddbaf732378b4b6(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), 
Sffb3bd546dd1ce6c27d1ac9c2ec68ad8); S528ca7ae10b9304dce67f7af7d73ca9f S56bd7107802ebe56c6918992f0608ec6 
= S94ad216f2d84942a661fb50cff62db12(0, 0, Sffb3bd546dd1ce6c27d1ac9c2ec68ad8, &Sb979c2934ac0b4ba3f08dabfdd1b2299); 
if (S56bd7107802ebe56c6918992f0608ec6 == S15cd745376460ee263646e4767748a83) { S56bd7107802ebe56c6918992f0608ec6 
= Sce7362cdbc237321a33646654654792e(&Sb979c2934ac0b4ba3f08dabfdd1b2299, 'S@wM', 'lock', S3ba5a6dd400eb5f7c49b56ddd13ddc22); 
if (S56bd7107802ebe56c6918992f0608ec6) { Sdc89a30d4c97fd8b60329797e2883ba8("Can't create lock file " 
<< Sbe05d559ccc3262d3e7d034ed3c56980); } }  do { S56bd7107802ebe56c6918992f0608ec6 = S1ea2e7b1ab595dd458729009b7e43039(&Sb979c2934ac0b4ba3f08dabfdd1b2299, 
S66dff7d037506ab17e996664a5c4eaca, &S8b94d212e321a4832223afb4d8f144b2); Sbda1f40e5c4ff203630569b4b9af3bf3; 
} while (S56bd7107802ebe56c6918992f0608ec6 == Sb36e48bcd9421fee71b8e586f8b88bb7); 
#else
  if (S522acd1179ffb040a67d6cd2eae0bfed == -1) {   Sf7ffeb350c9235cbf230290106a2d733(S4d682ec4eed27c53849758bc13b6e179, 
0777);  S522acd1179ffb040a67d6cd2eae0bfed = open(Sbe05d559ccc3262d3e7d034ed3c56980.c_str(), O_RDWR | 
O_CREAT, 0777); if (S522acd1179ffb040a67d6cd2eae0bfed == -1) 
#ifndef MINGW
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't open lock file " << Sbe05d559ccc3262d3e7d034ed3c56980 << " (" 
<< strerror(errno) << ")");
#else
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't open lock file " << Sbe05d559ccc3262d3e7d034ed3c56980);
#endif
  }  struct flock Sbc7b36fe4d2924e49800d9b3dc4a325c; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_type = F_WRLCK; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_whence = SEEK_SET; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_start = 0; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_len = 0; int Scb5e100e5a9a3e7f6d1fd97512215282 = fcntl(S522acd1179ffb040a67d6cd2eae0bfed, 
F_SETLKW, &Sbc7b36fe4d2924e49800d9b3dc4a325c); if (Scb5e100e5a9a3e7f6d1fd97512215282 == -1) Sdc89a30d4c97fd8b60329797e2883ba8("Can't lock database file: " 
<< strerror(errno));  
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = true; }   void S478df734a41b1d39ac090c596aa03a33::S0f42007614120ad55ee822b263a2982b(Se812b5a98988bad1d5b8df118cb6cc7f 
&S4d682ec4eed27c53849758bc13b6e179) {  if (!S4d682ec4eed27c53849758bc13b6e179.S95cc64dd2825f9df13ec4ad683ecf339.S6ababfc7c45c15a7da3db360b25546cb) 
return;   
#ifdef BEOS
 return; 
#endif
 
#ifdef WIN32
 Sa97b2c144243b2b9d2c593ec268b62f5 Sb37404a6d1ace1967f608146811fd739 = Se9fe22126bcdd89c9b1fe87ac3658672(S93abd35af93cd4151ac748cdf3684a67, 
0, 0, 1, 0); if (Sb37404a6d1ace1967f608146811fd739 == 0) 
#ifdef MINGW
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file"); 
#else
 Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file: " << strerror(errno)); 
#endif
 
#else
 
#ifdef macintosh
  S8744d5cbc40c3f66630f767f7b55d734(S8b94d212e321a4832223afb4d8f144b2); 
#else
  struct flock Sbc7b36fe4d2924e49800d9b3dc4a325c; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_type = F_UNLCK; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_whence = SEEK_SET; Sbc7b36fe4d2924e49800d9b3dc4a325c.l_start = 0; 
Sbc7b36fe4d2924e49800d9b3dc4a325c.l_len = 0; int Scb5e100e5a9a3e7f6d1fd97512215282 = fcntl(S522acd1179ffb040a67d6cd2eae0bfed, 
F_SETLKW, &Sbc7b36fe4d2924e49800d9b3dc4a325c); if (Scb5e100e5a9a3e7f6d1fd97512215282 == -1) Sdc89a30d4c97fd8b60329797e2883ba8("Can't unlock database file: " 
<< strerror(errno)); 
#endif
 
#endif
 S4cef2f30ac7d33419d00c1d93a090095 = false; }
